@@ -4,6 +4,7 @@ from emmet.core.polar import DielectricDoc
 from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
 from emmet.api.routes.dielectric.query_operators import DielectricQuery
 from emmet.api.core.global_header import GlobalHeaderProcessor
+from emmet.api.core.settings import MAPISettings
 
 
 def dielectric_resource(dielectric_store):
@@ -21,6 +22,7 @@ def dielectric_resource(dielectric_store):
         header_processor=GlobalHeaderProcessor(),
         tags=["Dielectric"],
         disable_validation=True,
+        timeout=MAPISettings().TIMEOUT,
     )
 
     return resource
