@@ -18,6 +18,9 @@ from emmet.api.routes.electronic_structure.query_operators import (
 )
 from emmet.core.electronic_structure import BSObjectDoc, DOSObjectDoc
 from emmet.api.core.global_header import GlobalHeaderProcessor
+from emmet.api.core.settings import MAPISettings
+
+timeout = MAPISettings().TIMEOUT
 
 
 def es_resource(es_store):
@@ -40,6 +43,7 @@ def es_resource(es_store):
         header_processor=GlobalHeaderProcessor(),
         tags=["Electronic Structure"],
         disable_validation=True,
+        timeout=timeout,
     )
 
     return resource
@@ -64,6 +68,7 @@ def bs_resource(es_store):
         enable_get_by_key=False,
         sub_path="/bandstructure/",
         disable_validation=True,
+        timeout=timeout,
     )
 
     return resource
@@ -106,6 +111,7 @@ def dos_resource(es_store):
         enable_get_by_key=False,
         sub_path="/dos/",
         disable_validation=True,
+        timeout=timeout
     )
 
     return resource
