@@ -1,6 +1,6 @@
 from maggma.api.resource import ReadOnlyResource
 from emmet.core.fermi import FermiDoc
-
+from emmet.api.core.global_header import GlobalHeaderProcessor
 from maggma.api.query_operator import PaginationQuery, SparseFieldsQuery
 
 
@@ -12,6 +12,7 @@ def fermi_resource(fermi_store):
             PaginationQuery(),
             SparseFieldsQuery(FermiDoc, default_fields=["task_id", "last_updated"]),
         ],
+        header_processor=GlobalHeaderProcessor(),
         tags=["Electronic Structure"],
         disable_validation=True,
     )
