@@ -10,6 +10,7 @@ from maggma.api.query_operator import (
 from emmet.api.routes.materials.query_operators import FormulaQuery, ChemsysQuery
 from emmet.api.routes.oxidation_states.query_operators import PossibleOxiStateQuery
 from emmet.api.core.global_header import GlobalHeaderProcessor
+from emmet.api.core.settings import MAPISettings
 
 
 def oxi_states_resource(oxi_states_store):
@@ -29,6 +30,7 @@ def oxi_states_resource(oxi_states_store):
         header_processor=GlobalHeaderProcessor(),
         tags=["Oxidation States"],
         disable_validation=True,
+        timeout=MAPISettings().TIMEOUT
     )
 
     return resource
