@@ -4,6 +4,7 @@ from emmet.core.polar import PiezoelectricDoc
 from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
 from emmet.api.routes.piezo.query_operators import PiezoelectricQuery
 from emmet.api.core.global_header import GlobalHeaderProcessor
+from emmet.api.core.settings import MAPISettings
 
 
 def piezo_resource(piezo_store):
@@ -21,6 +22,7 @@ def piezo_resource(piezo_store):
         header_processor=GlobalHeaderProcessor(),
         tags=["Piezoelectric"],
         disable_validation=True,
+        timeout=MAPISettings().TIMEOUT
     )
 
     return resource
