@@ -3,6 +3,7 @@ from maggma.api.query_operator import PaginationQuery, SparseFieldsQuery
 from emmet.api.routes.materials.query_operators import DeprecationQuery
 from emmet.api.core.global_header import GlobalHeaderProcessor
 from emmet.core.provenance import ProvenanceDoc
+from emmet.api.core.settings import MAPISettings
 
 
 def provenance_resource(provenance_store):
@@ -19,6 +20,7 @@ def provenance_resource(provenance_store):
         header_processor=GlobalHeaderProcessor(),
         tags=["Provenance"],
         disable_validation=True,
+        timeout=MAPISettings().TIMEOUT,
     )
 
     return resource
