@@ -2,6 +2,7 @@ from email import header
 from maggma.api.query_operator import PaginationQuery, SortQuery, SparseFieldsQuery
 from maggma.api.query_operator.dynamic import NumericQuery
 from maggma.api.resource import ReadOnlyResource
+from emmet.api.core.settings import MAPISettings
 
 from emmet.api.core.global_header import GlobalHeaderProcessor
 from emmet.api.routes.surface_properties.query_operators import ReconstructedQuery
@@ -22,6 +23,7 @@ def surface_props_resource(surface_prop_store):
         header_processor=GlobalHeaderProcessor(),
         tags=["Surface Properties"],
         disable_validation=True,
+        timeout=MAPISettings().TIMEOUT,
     )
 
     return resource
